@@ -54,12 +54,6 @@ try:
     screenWidth = _screen.get_width()
     screenHeight = _screen.get_height()
 
-    # We want to know what the tty is so we can send it to BrlAPI
-    # if possible.
-    #
-    (atom, format, data) = _root_window.property_get("XFree86_VT")
-    tty = data[0]
-
     # The bug that caused gnome-panel to crash is fixed in GTK 2.10.11.
     minimum_gtk_version = (100000 * 2) + \
                           (1000 * 10) + \
@@ -68,6 +62,12 @@ try:
                            (1000 * gtk.gtk_version[1]) + \
                             gtk.gtk_version[2]
     canPresentToolTips = (current_gtk_version >= minimum_gtk_version)
+
+    # We want to know what the tty is so we can send it to BrlAPI
+    # if possible.
+    #
+    (atom, format, data) = _root_window.property_get("XFree86_VT")
+    tty = data[0]
 except:
     pass
 
@@ -95,6 +95,7 @@ userCustomizableSettings = [
     "speechVerbosityLevel",
     "readTableCellRow",
     "enableSpeechIndentation",
+    "enableEchoByCharacter",
     "enableEchoByWord",
     "enableEchoBySentence",
     "enableKeyEcho",
@@ -104,8 +105,11 @@ userCustomizableSettings = [
     "enableFunctionKeys",
     "enableActionKeys",
     "enableNavigationKeys",
+    "enableDiacriticalKeys",
+    "enablePauseBreaks",
     "enableTutorialMessages",
     "enableMnemonicSpeaking",
+    "enablePositionSpeaking",
     "enableBraille",
     "enableBrailleContext",
     "enableBrailleGrouping",
@@ -115,6 +119,7 @@ userCustomizableSettings = [
     "brailleRolenameStyle",
     "brailleSelectorIndicator",
     "brailleLinkIndicator",
+    "brailleAlignmentStyle",
     "enableBrailleMonitor",
     "enableMagnifier",
     "enableMagLiveUpdating",
@@ -168,6 +173,7 @@ userCustomizableSettings = [
     "textAttributesBrailleIndicator",
     "enableProgressBarUpdates",
     "progressBarUpdateInterval",
+    "progressBarVerbosity",
     "enableContractedBraille",
     "brailleContractionTable",
     "enableMouseReview",
@@ -267,6 +273,19 @@ BRAILLE_LINK_8    = 0x80 # 10000000
 BRAILLE_LINK_BOTH = 0xc0 # 11000000
 brailleLinkIndicator = BRAILLE_LINK_BOTH
 
+# Braille alignment styles.  These say how to align text on the
+# edges of the braille display.  The brailleAlignmentMargin value
+# says how close to the edge of the braille the display the cursor
+# cell can get.  The brailleMaximumJump says how far we can jump
+# the display when aligning by word.
+#
+ALIGN_BRAILLE_BY_EDGE   = 0
+ALIGN_BRAILLE_BY_MARGIN = 1
+ALIGN_BRAILLE_BY_WORD   = 2
+brailleAlignmentMargin  = 3
+brailleMaximumJump      = 8
+brailleAlignmentStyle   = ALIGN_BRAILLE_BY_EDGE
+
 # Speech punctuation levels (see verbalizePunctuationStyle).
 #
 PUNCTUATION_STYLE_NONE = 3
@@ -362,6 +381,10 @@ enableBrailleContext    = True
 #
 enableBrailleGrouping   = False
 
+# The timeout (in milliseconds) to use for messages flashed in braille.
+#
+brailleFlashTime        = 5000
+
 # If True, enable braille monitor.
 #
 enableBrailleMonitor    = False
@@ -531,6 +554,12 @@ magSourceDisplay                 = ''
 #
 magTargetDisplay                 = ''
 
+# if True, enable character echo.
+# Note that it is allowable for both enableEchoByCharacter and enableKeyEcho
+# to be True
+#
+enableEchoByCharacter   = False
+
 # if True, enable word echo.
 # Note that it is allowable for both enableEchoByWord and enableKeyEcho
 # to be True
@@ -573,6 +602,10 @@ enableActionKeys        = True
 #
 enableNavigationKeys    = False
 
+# If True and key echo is enabled, echo Diacritical keys.
+#
+enableDiacriticalKeys   = False
+
 # If True, tutorial strings defined will be spoken.
 #
 enableTutorialMessages = False
@@ -581,6 +614,10 @@ enableTutorialMessages = False
 #
 enableMnemonicSpeaking = False
 
+# If true, position indexes  will be spoken automaticaly
+#
+enablePositionSpeaking = False
+
 # If True, show the main Orca window.
 #
 showMainWindow          = True
@@ -645,6 +682,18 @@ enableProgressBarUpdates = True
 #
 progressBarUpdateInterval = 10
 
+# When progress bar updates should be spoken, assuming they are enabled.
+# ALL means that any progress bar update will be spoken. APPLICATION
+# means that progress bar updates from the active application will be
+# spoken, even if they are not in the active window. WINDOW means that
+# the progress bar must be contained in the active window in order to
+# be spoken. The default verbosity level is APPLICATION.
+#
+PROGRESS_BAR_ALL = 0
+PROGRESS_BAR_APPLICATION = 1
+PROGRESS_BAR_WINDOW = 2
+progressBarVerbosity = PROGRESS_BAR_APPLICATION
+
 # Whether or not to present the 'read only' attribute of text areas
 # if we can detect they are read only or not.
 #
@@ -1041,7 +1090,11 @@ setScriptMapping(re.compile('[Ff]irefox'), "Mozilla")
 # version of Thunderbird, which chooses to now call itself by a different
 # name.
 #
-setScriptMapping(re.compile(_('Shredder')), "Thunderbird")
+#setScriptMapping(re.compile(_('Shredder')), "Thunderbird")
+#
+# Don't localize this. It seems to be messing us up. See bug 584103.
+#
+setScriptMapping(re.compile('Shredder'), "Thunderbird")
 
 # Translators: see the regular expression note above.  This is for
 # the Thunderbird e-mail application.
@@ -1282,6 +1335,18 @@ speechNodeLevelString = _("tree level %d")
 #
 speechNestingLevelString = _("Nesting level %d")
 
+# Translators: this is a indication of the focused icon and the
+# count of the total number of icons within an icon panel. An
+# example of an icon panel is the Nautilus folder view.
+#
+speechIconIndexString = _("on %(index)d of %(total)d")
+
+# Translators: this refers to the position of an item in a list
+# or group of objects, such as menu items in a menu, radio buttons
+# in a radio button group, combobox item in a combobox, etc.
+#
+speechGroupIndexString = _("%(index)d of %(total)d")
+
 # string to indicate end of printed line for braille displays:
 #
 disableBrailleEOL = False
@@ -1341,3 +1406,11 @@ brailleTableCellDelimiter = " "
 # sorted out just right.
 #
 useExperimentalSpeechProsody = True
+
+# If True, whenever a 'pause' keyword is found in a speech formatting
+# string, any string being created will be sent to the speech synthesis
+# system immediately.  This is for bug #585417 and allows for some
+# adaptation to how different systems handle queued speech.  For example,
+# some introduce unnaturally long pauses between requests to speak.
+#
+enablePauseBreaks = True
